/**
 * Test that the configuration module works.
 *
 * @author Christian Grothoff
 **/

#include "util/configuration.h"
#include "util/returnvalues.h"
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

int testConfig() {
  initConfiguration();
  free(setConfigurationString("FILES",
			      "gnunet.conf",
			      "testconfig.conf"));
  readConfiguration();
  if (NO == testConfigurationString("test",
				    "a",
				    "a")) {
    printf("[test]-a not mapped to a");
    return 1;
  }
  if (0 != strcmp("b",
		  getConfigurationString("test",
					 "b"))) {
    printf("[test]-b not mapped to b");
    return 1;
  }
  if (5 != getConfigurationInt("test",
			       "five")) {
    printf("[test]-five not mapped to 5");
    return 1;
  }
  free(setConfigurationString("more",
			      "c",
			      "d"));
  if (NO == testConfigurationString("more",
				    "c",
				    "d")) {
    printf("[more]-c not re-mapped to d");
    return 1;
  }  
  if (42 != getConfigurationInt("more",
				"five")) {
    printf("[more]-five not mapped to 42");
    return 1;
  }
  if (NO == testConfigurationString("last",
				    "test",
				    "hello/world")) {
    printf("string substitution did not work: >>%s<<\n",
	   getConfigurationString("last",
				  "test"));
    return 1;
  }
  if (NO == testConfigurationString("last",
				    "boom",
				    "1 2 3 testing")) {
    printf("string enclosing with \"'s did not work: >>%s<<\n",
	   getConfigurationString("last",
				  "boom"));
    return 1;
  }
  if (NO == testConfigurationString("last",
				    "trailing",
				    "YES")) {
    printf("confused with trailing spaces: >>%s<<\n",
	   getConfigurationString("last",
		   		  "trailing"));
  }
			
  doneConfiguration();
  return 0;
}


int main() {
  int failureCount = 0;

  failureCount += testConfig();
  
  if (failureCount == 0) 
    return 0;
  else {
    printf("\n\n%d TESTS FAILED!\n\n",failureCount);
    return -1;
  } 
}
